@@ -9,10 +9,13 @@ monotypic <- function(refl, nr.member = 1, reflist.type = c('Turboveg', 'EDIT'),
 # names(taxa)[names(taxa)=='TAXONRANK'] <- 'TaxonRank'
  mono <- data.frame(Parent_NR = AG, Parent_Name=taxa$TaxonName[match(AG, taxa$TaxonUsageID)], Parent_Rank = taxa$TaxonRank[match(AG, taxa$TaxonUsageID)], MEMBER_NR=taxa$TaxonUsageID[match(AG,taxa$IsChildTaxonOfID)], MEMB_NAME=taxa$TaxonName[match(AG,taxa$IsChildTaxonOfID)], MEMB_Rank=taxa$TaxonRank[match(AG,taxa$IsChildTaxonOfID)])
  NbChildren <- as.integer(sapply(mono$MEMBER_NR, function(x) nrow(child(x, refl=refl, reflist.type=reflist.type, quiet=TRUE)) ), use.names=FALSE)
+mono$NbChildren <- NbChildren
+# AGG_NR,N,8,0  AGG_taxonR,C,13	MEMBER_NR,N,9,0	MEMB_NAME,C,67	MEMB_taxon,C,14
 # mono$NbChildren <- unlist(mono$NbChildren)
 #mono$NbChildren ch <- child(x, refl=refl, reflist.type=reflist.type) 
- if(write) write.csv2(mono[NbChildren == nr.member,], filename, row.names = FALSE)
- invisible(mono)
+# if(write) write.csv2(mono[NbChildren == nr.member,], filename, row.names = FALSE)
+ if(write) write.csv2(mono, filename, row.names = FALSE)
+invisible(mono)
 }
 
 tv.mono <- function(...) stop('Deprecated. Use monotypic() instead.')
