@@ -1,6 +1,7 @@
-vw.survey <- function(searchstring, ...) {
+vw.survey <- function(searchstring, server, ...) {
 #  require(httr)
-  surveys <- fromJSON('http://botanik3.botanik.uni-greifswald.de/floradb-rs/service/v1/surveys?portalId=3')$survey
+  if(missing(server)) server <- 'botanik3.botanik.uni-greifswald.de'
+  surveys <- fromJSON(paste('http://', server, '/floradb-rs/service/v1/surveys?portalId=3', sep=''))$survey
   if(is.numeric(searchstring)) {
     df <- data.frame(Projekt_ID = surveys[grep(searchstring, surveys$id),'id'], Projekttitel = surveys[grep(searchstring, surveys$id),'title'], Kustode= paste(surveys[grepl(searchstring, surveys$title),'owner']$firstName, surveys[grepl(searchstring, surveys$title),'owner']$lastName))
   } else {
@@ -10,12 +11,13 @@ vw.survey <- function(searchstring, ...) {
 }
 
 
-vw.site <- function(user, password, survey, basket, ...) {
+vw.site <- function(user, password, survey, basket, server, ...) {
 #  require(httr)
+  if(missing(server)) server <- 'botanik3.botanik.uni-greifswald.de'
   if(!missing(basket)) stop('Webservices for vegetation plot baskets are not yet (Nov 2015) implemented in vegetweb.de')
   message('This is a test implementation. Passwords will be send through http, i.e. unsecured.')
-  r <- GET(paste('http://botanik3.botanik.uni-greifswald.de/floradb-rs/service/v1/snapshots', survey[1], '?occurrenceAttribute=COVERAGE_MEAN', sep='/'),  authenticate(user, password), add_headers("Accept : application/json")) 
-  stop_for_status(x=r, task = 'access the dataset.')
+  r <- GET(paste('http:/', server, 'floradb-rs/service/v1/snapshots', survey[1], '?occurrenceAttribute=COVERAGE_MEAN', sep='/'),  authenticate(user, password), add_headers("Accept : application/json")) 
+  stop_for_status(x = r, task = 'access the dataset.')
   data <- content(r, "parsed", "application/json")
   nbplots <- length(unique(sapply(data$data, '[[', 'sampleUUID')))
   message('Number of plots: ', nbplots)
@@ -25,7 +27,7 @@ vw.site <- function(user, password, survey, basket, ...) {
   site <- do.call(rbind.data.frame, data$header) 
 if(length(survey) > 1)
    for(i in 2:length(survey)) {
-     r <- GET(paste('http://botanik3.botanik.uni-greifswald.de/floradb-rs/service/v1/snapshots', survey[1],  '?occurrenceAttribute=COVERAGE_MEAN', sep='/'),  authenticate(user, password), add_headers("Accept : application/json"))
+     r <- GET(paste('http:/', server, 'floradb-rs/service/v1/snapshots', survey[1],  '?occurrenceAttribute=COVERAGE_MEAN', sep='/'),  authenticate(user, password), add_headers("Accept : application/json"))
 	  stop_for_status(x=r, 'access the dataset.')
     data <- content(r, "parsed", "application/json")
     assign(paste(fields,i, sep='.'), names(data$header[[1]]))
@@ -49,8 +51,9 @@ if(length(survey) > 1)
 }}
 
 
-vw.veg <- function(user, password, survey, basket, taxeval = TRUE, ...) {
+vw.veg <- function(user, password, survey, basket, taxeval = TRUE, server, ...) {
 #  require(httr)
+  if(missing(server)) server <- 'botanik3.botanik.uni-greifswald.de'
   message('This is a test implementation. Passwords will be send through http, i.e. unsecured.')
   if(is.character(survey)) {
     surveyid <- vw.survey(survey)
@@ -58,7 +61,7 @@ vw.veg <- function(user, password, survey, basket, taxeval = TRUE, ...) {
       surveyid <- surveyid$id
   } else surveyid <- survey
   if(!missing(basket)) stop('Webservices for vegetation plot baskets are not yet (Nov 2015) implemented in vegetweb.de')
-  r <- GET(paste('http://botanik3.botanik.uni-greifswald.de/floradb-rs/service/v1/snapshots', surveyid, '?occurrenceAttribute=COVERAGE_MEAN', sep='/'),  authenticate(user, password), add_headers("Accept : application/json"))
+  r <- GET(paste('http:/', server, 'floradb-rs/service/v1/snapshots', surveyid, '?occurrenceAttribute=COVERAGE_MEAN', sep='/'),  authenticate(user, password), add_headers("Accept : application/json"))
   stop_for_status(x=r, 'access the dataset.')
   data <- content(r, "parsed", "application/json")
   nbplots <- length(unique(sapply(data$data, '[[', 'sampleUUID')))
